# cadqueryhelper
CadQuery Helper library.<br />
Code for shape primitives, looping groups of shapes, hinges, and various wave operations.

![](documentation/image/shape/43.png)

## Documentation
## Index
* [Grid](./documentation/grid.md)
* [Hinge](./documentation/hinge.md)
* [Shapes](./documentation/shapes.md)
* [Wave](./documentation/wave.md)

## Changes
* [Changelog](./changes.md)

## Dependencies
* [CadQuery](https://github.com/CadQuery/cadquery)
  
---

### Installation
To install CadQuery Helper directly from GitHub, run the following `pip` command:

	pip install git+https://github.com/medicationforall/cadqueryhelper

**OR**

### Local Installation
From the cloned cadqueryhelper directory run.

	pip install ./

---

## Running Example Scripts
* From the root of the project run of example_runner.py:

``` bash
C:\Users\<user>\cadqueryhelper>python example_runner.py
```

**OR**

* From the root of the project run one of the example scripts:


``` bash
C:\Users\<user>\cadqueryhelper>python ./example/shape/arrow.py
```
